@@ -1,6 +1,6 @@
 from fastapi import Request
 
-from magicapi import app
+from magicapi import g
 
 from fastapi.responses import JSONResponse
 
@@ -27,7 +27,7 @@ class TwilioException(MagicException):
     pass
 
 
-@app.exception_handler(MagicException)
+@g.app.exception_handler(MagicException)
 def backend_exception_handler(request: Request, exc: MagicException):
     return JSONResponse(
         status_code=exc.status_code,
