@@ -37,6 +37,10 @@ def add_tasks_and_process_time_middleware(new_app):
         g.request = request
         g.app = new_app
         print("url path", request.url.path, "***url", request.url)
+        context = request.scope['aws.context']
+        print('context', context)
+        print('contect_dict', context.__dict__)
+        print('sls sdk', context.serverless_sdk)
         response = await call_next(request)
         if response.status_code == 404 and g.settings.save_calls:
             await save_not_found_from_request(request)
@@ -104,13 +108,14 @@ def create_handler(app):
     def handler(event, context):
         """Handler to give to lambda... which wraps FastAPI"""
         if event.get("source") in ["aws.events", "serverless-plugin-warmup"]:
-            print("Lambda is warm!")
+            print("Lambda is warm, now!!!")
             return {}
         print('context', context)
         print('contect_dict', context.__dict__)
         print('sls sdk', context.serverless_sdk)
         asgi_handler = Mangum(app, api_gateway_base_path=g.settings.stage)
         response = asgi_handler(event, context)
+        print('response', response)
         return response
 
     g.handler = handler
