@@ -28,7 +28,7 @@ def find_file(glob_string: str, levels: int = 10):
         d = d.parent
 
 
-class Settings(BaseSettings):
+class MagicSettings(BaseSettings):
     app_name: str = "GOAT Server"
     version: str = "0.0.1"
 
@@ -87,11 +87,12 @@ class Settings(BaseSettings):
         env_file = find_file(glob_string="*.env") or ".env"
 
 
+
 # If you want to make the env variables from .env available
 # from dotenv import load_dotenv
 # if os.path.exists(env_path):
 #     load_dotenv(env_path)
 
-settings = Settings()
+# settings = MagicSettings()
 
-config_firestore(settings.service_account_name)
+# config_firestore(settings.service_account_name)
